searchNodes=[{"doc":"CPU utility functions.Functions to read and calculate CPU utilization for a given process.NOTE: Only *nix systems supported.","ref":"CpuUtil.html","title":"CpuUtil","type":"module"},{"doc":"Calculate CPU utilization given 2 readings.Algorithmuser_util = 100 (utime_after - utime_before) / (time_total_after - time_total_before); sys_util = 100 (stime_after - stime_before) / (time_total_after - time_total_before);Usage&gt; pid = CpuUtil.os_pid() &gt; cores = CpuUtil.num_cores() &gt; u1 = CpuUtil.pid_util(pid) &gt; Process.sleep(1000) &gt; u2 = CpuUtil.pid_util(pid) &gt; CpuUtil.calc_pid_util(u1, u2, cores) %{ user: 2.0, sys: 0.5, total: 2.5 }Referenceshttps://stackoverflow.com/questions/1420426/how-to-calculate-the-cpu-usage-of-a-process-by-pid-in-linux-from-c/1424556Examplesiex&gt; prev = %{total: 99, stats: %{utime: 20, stime: 10}} iex&gt; curr = %{total: 248, stats: %{utime: 29, stime: 18}} iex&gt; CpuUtil.calc_pid_util(prev, curr) %{sys: 5.4, total: 11.4, user: 6.0} iex&gt; prev = %{total: 99, stats: %{utime: 20, stime: 10}} iex&gt; curr = %{total: 248, stats: %{utime: 29, stime: 18}} iex&gt; CpuUtil.calc_pid_util(prev, curr, 2, 2) %{sys: 10.74, total: 22.82, user: 12.08}","ref":"CpuUtil.html#calc_pid_util/4","title":"CpuUtil.calc_pid_util/4","type":"function"},{"doc":"Get the number of CPU Cores.Examplesiex&gt; {:ok, cores} = CpuUtil.core_count() iex&gt; is_integer(cores) true","ref":"CpuUtil.html#core_count/0","title":"CpuUtil.core_count/0","type":"function"},{"doc":"Get the cpu for the given os_pid and number of cores.Blocks the calling process for time (1) seconds to collect the before and after samples.","ref":"CpuUtil.html#get_cpu_util/2","title":"CpuUtil.get_cpu_util/2","type":"function"},{"doc":"Get the current OS PID.Examplesiex&gt; CpuUtil.getpid() |&gt; is_integer() true","ref":"CpuUtil.html#getpid/0","title":"CpuUtil.getpid/0","type":"function"},{"doc":"Read the CPU's average load.Examplesiex&gt; {float, &quot;&quot;} = CpuUtil.loadavg() |&gt; Float.parse() iex&gt; is_float(float) true","ref":"CpuUtil.html#loadavg/1","title":"CpuUtil.loadavg/1","type":"function"},{"doc":"Get the number of CPU Cores.Deprecated! Use CpuUtil.core_count/0 instead.","ref":"CpuUtil.html#num_cores/0","title":"CpuUtil.num_cores/0","type":"function"},{"doc":"Get the current OS stat.Read the total time from /proc/statRead the PID stats from /proc/&lt;PID&gt;/statReturn a map:%{ total: integer() stats: proc_pid_stat() }Examplesiex&gt; fields = ~w(cmaj_flt cmin_flt cstime cutime flags maj_flt min_flt pgrp pid ppid sid ...&gt; state stime tcomm tty_nr tty_pgrp utime)a iex&gt; util = CpuUtil.pid_util(CpuUtil.getpid()) iex&gt; Map.keys(util) == ~w(stats total)a and is_integer(util.total) and ...&gt; Map.keys(util.stats) == fields true","ref":"CpuUtil.html#pid_util/1","title":"CpuUtil.pid_util/1","type":"function"},{"doc":"Calculate the OS process CPU Utilization.Similar to CpuUtil.calc_pid_util/4 except that it takes the raw binary data read from {&quot;/proc/stat&quot;, &quot;/proc/&lt;os_pid&gt;/stat&quot;}.Examplesiex&gt; prev = {&quot;cpu 11380053 51 3665881 1638097578 194367 213 149713 110770 0&quot;, ...&gt; &quot;9930 (beam.smp) S 24113 9930 24113 34817 9930 4202496 189946 5826 0 0 12025 1926 &quot; &lt;&gt; ...&gt; &quot;0 0 20 0 28 0 275236728 3164401664 42600 18446744073709551615 4194304 7475860 &quot; &lt;&gt; ...&gt; &quot;140732561929584 140732561927920 256526653091 0 0 4224 134365702 18446744073709551615 &quot; &lt;&gt; ...&gt; &quot;0 0 17 3 0 0 0 0 0&quot;} iex&gt; curr = {&quot;cpu 11380060 51 3665883 1638099001 194367 213 149713 110770 0&quot;, ...&gt; &quot;9930 (beam.smp) S 24113 9930 24113 34817 9930 4202496 189950 5826 0 0 12027 1927 &quot; &lt;&gt; ...&gt; &quot;0 0 20 0 28 0 275236728 3164401664 42600 18446744073709551615 4194304 7475860 &quot; &lt;&gt; ...&gt; &quot;140732561929584 140732561927920 256526653091 0 0 4224 134365702 18446744073709551615 &quot; &lt;&gt; ...&gt; &quot;0 0 17 3 0 0 0 0 0&quot;} iex&gt; CpuUtil.process_util(prev, curr) %{sys: 0.1, total: 0.2, user: 0.1}","ref":"CpuUtil.html#process_util/3","title":"CpuUtil.process_util/3","type":"function"},{"doc":"Read the OS stat data.Reads /proc/statParses the first line ('cpu')Converts the numbers (string) to integersExamplesiex&gt; [&quot;cpu&quot; | numbers] = CpuUtil.stat() iex&gt; length(numbers) == 10 and Enum.all?(numbers, &amp;is_integer/1) true","ref":"CpuUtil.html#stat/0","title":"CpuUtil.stat/0","type":"function"},{"doc":"Parse the data read from /proc/stat.Extract the first line &quot;cpu&quot; and convert numbers to integers.Examples iex&gt; CpuUtil.stat(&quot;cpu 12010882 75 3879349 1731141995 200300 225 154316 115184 0&quot;) [&quot;cpu&quot;, 12010882, 75, 3879349, 1731141995, 200300, 225, 154316, 115184, 0]","ref":"CpuUtil.html#stat/1","title":"CpuUtil.stat/1","type":"function"},{"doc":"Get the current OS &lt;PID&gt; stat.Read /proc/&lt;PID&gt;/stat (single line of space separated fields)Parse the fields and convert any numbers (string) to integersReturns a map of of the fields (atom keys) per the following definition: pid process id tcomm filename of the executable state state (R is running, S is sleeping, D is sleeping in an uninterruptible wait, Z is zombie, T is traced or stopped) ppid process id of the parent process pgrp pgrp of the process sid session id tty_nr tty the process uses tty_pgrp pgrp of the tty flags task flags min_flt number of minor faults cmin_flt number of minor faults with child's maj_flt number of major faults cmaj_flt number of major faults with child's utime user mode jiffies stime kernel mode jiffies cutime user mode jiffies with child's cstime kernel mode jiffies with child'sExamplesiex&gt; CpuUtil.stat_pid(CpuUtil.getpid()) |&gt; Map.keys() ~w(cmaj_flt cmin_flt cstime cutime flags maj_flt min_flt pgrp pid ppid sid state stime tcomm tty_nr tty_pgrp utime)a # iex&gt; str = &quot;9731 (beam.smp) S 9730 9730 9730 0 -1 4202496 13784 3143 0 0 93 11 0 0 20 0 &quot; # iex&gt; str = str &lt;&gt; &quot;28 0 291467565 2993774592 15101 18446744073709551615 4194304 7475860 &quot; # iex&gt; str = str &lt;&gt; &quot;140732224047216 140732224045552 256526653091 0 0 4224 16902 &quot; # iex&gt; str = str &lt;&gt; &quot;18446744073709551615 0 0 17 3 0 0 0 0 0&quot; iex&gt; content = &quot;9731 (beam.smp) S 9730 9730 9730 0 -1 4202496 13784 3143 0 0 93 11 0 0 &quot; &lt;&gt; ...&gt; &quot;20 0 291467565 2993774592 15101 18446744073709551615 4194304 7475860 140732224047216 &quot; &lt;&gt; ...&gt; &quot;140732224047216 140732224045552 256526653091 0 0 4224 16902 18446744073709551615 0 &quot; &lt;&gt; ...&gt; &quot;0 17 3 0 0 0 0 0&quot; iex&gt; CpuUtil.stat_pid(content) %{ cmaj_flt: 0, cmin_flt: 3143, cstime: 0, cutime: 0, flags: 4202496, maj_flt: 0, min_flt: 13784, pgrp: 9730, pid: 9731, ppid: 9730, sid: 9730, state: &quot;S&quot;, stime: 11, tcomm: &quot;(beam.smp)&quot;, tty_nr: 0, tty_pgrp: &quot;-1&quot;, utime: 93 }","ref":"CpuUtil.html#stat_pid/1","title":"CpuUtil.stat_pid/1","type":"function"},{"doc":"Get the total_time from the given list.Takes the output of CpuUtil.stat/0 and returns the total time.Examplesiex&gt; data = [&quot;cpu&quot;, 12010882, 75, 3879349, 1731141995, 200300, 225, 154316, 115184, 0] iex&gt; CpuUtil.stat_total_time(data) 1747502326","ref":"CpuUtil.html#stat_total_time/1","title":"CpuUtil.stat_total_time/1","type":"function"},{"doc":"Get the total_time.Return the total time (from /proc/stat) as an integer.Examplesiex&gt; CpuUtil.total_time() |&gt; is_integer() true","ref":"CpuUtil.html#total_time/0","title":"CpuUtil.total_time/0","type":"function"},{"doc":"Get the total time given the contents of &quot;/proc/stat&quot;Examplesiex&gt; CpuUtil.total_time(&quot;cpu 12010882 75 3879349 1731141995 200300 225 154316 115184 0&quot;) 1747502326","ref":"CpuUtil.html#total_time/1","title":"CpuUtil.total_time/1","type":"function"},{"doc":"","ref":"CpuUtil.html#t:proc_pid_stat/0","title":"CpuUtil.proc_pid_stat/0","type":"type"},{"doc":"","ref":"CpuUtil.html#t:util/0","title":"CpuUtil.util/0","type":"type"},{"doc":"","ref":"CpuUtil.html#t:util_stat/0","title":"CpuUtil.util_stat/0","type":"type"},{"doc":"CpuUtilGet CPU utilization information on Linux systems.","ref":"readme.html","title":"CpuUtil","type":"extras"},{"doc":"If available in Hex, the package can be installed by adding cpu_util to your list of dependencies in mix.exs:def deps do [ {:cpu_util, &quot;~&gt; 0.6&quot;} ] endDocumentation can be generated with ExDoc and published on HexDocs. Once published, the docs can be found at https://hexdocs.pm/cpu_util.","ref":"readme.html#installation","title":"CpuUtil - Installation","type":"extras"},{"doc":"CpuUtil is Copyright (c) 2020-2023 E-MetroTelThe source code is released under the MIT License.Check LICENSE for more information.","ref":"readme.html#license","title":"CpuUtil - License","type":"extras"},{"doc":"The MIT License (MIT)Copyright (c) 2020 E-MetroTelPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html","title":"LICENSE","type":"extras"}]